==> V1.0.0.zip: fe_kd_server/src/utils/api.js <==
// let host = 'http://192.168.31.152:8090'
// let host = 'http://192.168.31.152:1010'
// let host = 'http://192.168.31.125:9090'//林
// let host = 'http://192.168.31.152:9090'//榕
// let host = 'http://192.168.31.137:9090'//陈
// let host = 'http://192.168.31.140:9090'//7

let uploadURL = 'http://8.134.8.197:8001'
let host = ''
if(process.env.NODE_ENV === 'development'){
  host = 'http://122.9.154.146'
}

export default {
  logins: `${host}/liuwanr/userInfo/adminLogins`, //登录 

  fileupload: `${uploadURL}/oss/manage/fileupload`,
  updateLogInNumber: `${host}/liuwanr/userInfo/updateLogInNumber`, //用户登录修改登录次数和登陆时间
  uploadUserAvatars: `${host}/liuwanr/userInfo/uploadUserAvatars`, //上传头像
  queryProvince: `${host}/liuwanr/province/queryProvince`, //查询省份
  queryCity: `${host}/liuwanr/city/queryCity`, //查询城市
  querySchoolData: `${host}/liuwanr/customer/querySchool`, //根据学校名称查询学校信息

  queryAccountIsExist:`${host}/liuwanr/userInfo/queryAccountIsExist`,//查询员工，学生账号是否存在接口
  queryWorkNumberIsExist:`${host}/evaluation/tms/userInfo/queryWorkNumberIsExist`,//查询学号是否存在
  queryWorkNumberIsExist1:`${host}/liuwanr/userInfo/queryWorkNumberIsExist`,//查询工号是否存在
  querySchool: `${host}/liuwanr/customer/querySchool`, //根据学校名称查询学校信息
 
  queryPersonalCenter:`${host}/liuwanr/personalCenter/queryPersonalCenter`,
  addStaffPro: `${host}/liuwanr/staffProfessionalArchitecture/addStaffProfessionalArchitecture`, //添加员工专业
  queryStaffPro: `${host}/liuwanr/staffProfessionalArchitecture/queryAllStaffProfessionalArchitecture`, //查询员工专业
  deleteStaffPro: `${host}/liuwanr/staffProfessionalArchitecture/deleteStaffProfessionalArchitecture`, //删除员工专业
  deleteStaffGrade: `${host}/liuwanr/staffGrade/deleteStaffGrade`, //删除员工部门
  updateStaffPro: `${host}/liuwanr/staffProfessionalArchitecture/updateStaffProfessionalArchitecture`, //编辑员工专业
  queryStaffGrade: `${host}/liuwanr/staffGrade/queryStaffGrade`, //查询员工部门
  queryStaffGradeDetails: `${host}/liuwanr/staffGrade/queryStaffGradeDetails`, //查询员工部门详情
  addStaffGrade: `${host}/liuwanr/staffGrade/addStaffGrade`, //新增员工部门
  updateStaffGrade: `${host}/liuwanr/staffGrade/updateStaffGrade`, //编辑员工部门
  queryCourseDiscipline: `${host}/liuwanr/course/queryCourseDiscipline`, //查询课程学科
  queryCourseProfessionalClass: `${host}/liuwanr/course/queryCourseProfessionalClass`, //查询专业类
  queryCourseProfessional: `${host}/liuwanr/course/queryCourseProfessional`, //查询专业
  queryPhone: `${host}/liuwanr/user/queryPhone`, //查询电话是否存在
  queryEmail: `${host}/liuwanr/user/queryEmail`, //查询邮箱是否存在
  queryStaffPAN:`${host}/liuwanr/staffProfessionalArchitecture/queryStaffPAN`,//查询员工专业是否存在

  // 个人中心
  userinfo:`${host}/evaluation/tms/userInfo/userinfo`,
  userinfoUpdate:`${host}/evaluation/tms/userInfo/updateUser`,
  sendEmailCode:`${host}/evaluation/tms/user/sendEmailCode`,//发送邮箱验证码
  bingEmail:`${host}/evaluation/tms/user/bingEmail`,//邮箱验证并更新
  sendPhoneCode:`${host}/evaluation/tms/user/sendPhoneCode`,//发送手机验证码
  bindPhone:`${host}/evaluation/tms/user/bindPhone`,//校验手机验证码

  // 测评管理
  list: `${host}/evaluation/tms/questions/list`, //分页加条件查询试题信息
  info: `${host}/evaluation/tms/evaluationrules/info`, //测评规则信息的展示
  update: `${host}/evaluation/tms/evaluationrules/update`, //修改测评规则信息
  delete: `${host}/evaluation/tms/questions/delete`, //批量删除试题信息
  download: `${host}/evaluation/tms/questions/download`, //excel模板文件下载
  import: `${host}/evaluation/tms/questions/import`, //通过excel批量导入
  infoId: `${host}/evaluation/tms/questions/info/`, //根据试题id查询试题详情信息
  isenable: `${host}/evaluation/tms/questions/isenable`, //是否禁用试题
  save: `${host}/evaluation/tms/questions/save`, //新增一道试题
  questionsUpdate: `${host}/evaluation/tms/questions/update`, //根据试题id修改试题信息
  upload: `${host}/evaluation/tms/questions/upload`, //excel模板文件上传
  export_failure: `${host}/evaluation/tms/questions/export_failure`, //导出导入失败的数据和失败原因

  expDelete: `${host}/evaluation/tms/exp/delete`, //删除实验教学
  expList: `${host}/evaluation/tms/exp/list`, //实验教学列表
  expSave: `${host}/evaluation/tms/exp/save`, //添加实验教学
  expUpdate: `${host}/evaluation/tms/exp/update`, //修改实验教学
  expInfo: `${host}/evaluation/tms/exp/getById/`, //实验教学详情
  expCheck: `${host}/evaluation/tms/exp/check`, //实验名称判重
  getInvitationCode: `${host}/evaluation/tms/exp/getInvitationCode`, //查询邀请码是否存在
  expInfo1: `${host}/evaluation/tms/exp/upload`, //实验教学提前结束

  queryAllManagements: `${host}/project/ProjectManagement/queryAllManagementsByKD`, //项目管理列表信息
  queryManagements: `${host}/project/ProjectManagement/KDqueryManagements`, //项目管理列表信息
  addRole: `${host}/project/ProjectManagement/addRole`, //新增案例对象
  avgValues: `${host}/project/ProjectManagement/avgValues`, //平均分配分值
  getByRoleId: `${host}/project/ProjectManagement/getByRoleId`, //根据角色id查询信息
  getByjudgmentPointsId: `${host}/project/ProjectManagement/getByjudgmentPointsId`, //实验任务表格信息的展示
  queryAllJudgmentPoints: `${host}/project/ProjectManagement/queryAllJudgmentPoints`, //添加判分点面板的数据展示+条件筛选
  getProjectId: `${host}/project/ProjectManagement/getTrdingJudgmentPointsByKD`, //根据项目管理id查询对应信息
  updateProjectManagement: `${host}/project/ProjectManagement/newUpdateProjectManagementByKD`, //编辑项目管理
  addProjectManagement: `${host}/project/ProjectManagement/newProjectManagementByKD`, //添加项目管理
  removeProjectManagement: `${host}/project/ProjectManagement/removeProjectManagement`, //删除
  getJudgmentPoints: `${host}/project/ProjectManagement/getJudgmentPoints`, //复制项目获取数据
  updateRole: `${host}/project/ProjectManagement/updateRole`, //修改实验数据—角色信息
  isNameExistis: `${host}/project/ProjectManagement/isNameExistis`, //项目名称是否存在
  QueryPfdInformation: `${host}/judgment/pointOfJudgement/queryPfdInformation`, //判分点详细信息
  queryUserIds:`${host}/liuwanr/userInfo/queryUserIds`,

  // 学生管理
  addStudent: `${host}/evaluation/tms/student/addStudent`,
  daleteStudent: `${host}/evaluation/tms/student/daleteStudent`,
  disableAccount: `${host}/evaluation/tms/student/disableAccount`,
  queryStudent: `${host}/evaluation/tms/student/queryStudent`,
  reSetPassword: `${host}/evaluation/tms/student/reSetPassword`,
  updateStudent: `${host}/evaluation/tms/student/updateStudent`,
  download: `${host}/evaluation/tms/student/download`,
  uploadFile: `${host}/evaluation/tms/student/uploadFile`,
  export_failure: `${host}/evaluation/tms/student/export_failure`,
  queryAccountStudent:`${host}/evaluation/tms/student/queryAccount`,
  queryStudentData:`${host}/evaluation/tms/student/queryStudentData`,

  // 员工管理
  addStaff: `${host}/evaluation/tms/system/addStaff`,
  daleteBatchStaff: `${host}/evaluation/tms/system/daleteBatchStaff`,
  queryStaff: `${host}/evaluation/tms/system/queryStaff`,
  querystaffDetail: `${host}/evaluation/tms/system/querystaffDetail`,
  updateStaff: `${host}/evaluation/tms/system/updateStaff`,
  downloadStaff: `${host}/evaluation/tms/system/download`,
  export_failureStaff: `${host}/evaluation/tms/system/export_failure`,
  uploadFileStaff: `${host}/evaluation/tms/system/uploadFile`,
  queryAccountStaff:`${host}/evaluation/tms/system/queryAccount`,
  resetPwd:`${host}/evaluation/tms/system/resetPwd`,

  // 角色权限
  rolePermissionList:`${host}/evaluation/sys-permission/rolePermissionList`,
  saveRolePermission:`${host}/evaluation/sys-permission/saveRolePermission`,
  updateRolePermission:`${host}/evaluation/sys-permission/updateRolePermission`,
  delRolePermission:`${host}/evaluation/sys-permission/delRolePermission`,
  queryPermissionArrById:`${host}/evaluation/sys-permission/queryPermissionArrById`,
  roleTree:`${host}/evaluation/sys-permission/tree`,

  // 成绩管理
  addReport: `${host}/evaluation/Achievement/addReport`,
  deleteReport: `${host}/evaluation/Achievement/deleteReport`,
  deleteReportById: `${host}/evaluation/Achievement/deleteReportById`,
  exportAchievement:`${host}/evaluation/Achievement/exportAchievement`,
  queryAchievement:`${host}/evaluation/Achievement/list`,
  queryAchievementNew:`${host}/evaluation/Achievement/newList`,
  reportList:`${host}/evaluation/Achievement/reportList`,
  getTeachAchievement: `${host}/evaluation/Achievement/getTeachAchievement`,
  queryEvaluationReport:`${host}/evaluation/Achievement/queryEvaluationReport`,
  queryReport:`${host}/evaluation/Achievement/queryReport`,
  getReport: `${host}/evaluation/Achievement/getReport`,
  editScore: `${host}/evaluation/Achievement/editScore`,
  getItemContentByIds:`${host}/kdSys/getItemContentByIds`,

  // 教师评语
  addComment: `${host}/evaluation/Achievement/addComment`,
  queryComment: `${host}/evaluation/Achievement/queryComment`,
  updateComment:`${host}/evaluation/Achievement/updateComment`,

  // 老师签名照
  daleteSignature: `${host}/evaluation/signature/deleteSignature`,
  querySignature: `${host}/evaluation/signature/querySignature`,
  uploadSignature:`${host}/evaluation/signature/uploadSignature`,
  reportSignature:`${host}/evaluation/signature/reportSignature`,
  selectSignature:`${host}/evaluation/signature/selectSignature`,

  // 科大川大
  queryListTrading: `${host}/judgment/tradingJudgmentPoints/query`,
  queryDetailsTrading: `${host}/judgment/tradingJudgmentPoints/queryDetails`,
  queryPoint: `${host}/kdSys/queryPoint`,
  querySubject: `${host}/kdSys/querySubject`,
  queryItem: `${host}/kdSys/queryItem`,
}

==> V1.0.1.zip: fe_kd_server/src/utils/api.js <==
// let host = 'http://192.168.31.152:8090'
// let host = 'http://192.168.31.152:1010'
// let host = 'http://192.168.31.125:9090'//林
// let host = 'http://192.168.31.151:9090'//榕
// let host = 'http://192.168.31.137:9090'//陈
// let host = 'http://192.168.31.140:9090'//7

let uploadURL = 'http://8.134.8.197:8001'
let host = ''
if(process.env.NODE_ENV === 'development'){
  host = 'http://122.9.154.146'
}

export default {
  logins: `${host}/liuwanr/userInfo/adminLogins`, //登录 
  queryToken: `${host}/liuwanr/userInfo/queryToken`,

  fileupload: `${uploadURL}/oss/manage/fileupload`,
  updateLogInNumber: `${host}/liuwanr/userInfo/updateLogInNumber`, //用户登录修改登录次数和登陆时间
  uploadUserAvatars: `${host}/liuwanr/userInfo/uploadUserAvatars`, //上传头像
  queryProvince: `${host}/liuwanr/province/queryProvince`, //查询省份
  queryCity: `${host}/liuwanr/city/queryCity`, //查询城市
  querySchoolData: `${host}/liuwanr/customer/querySchool`, //根据学校名称查询学校信息

  queryAccountIsExist:`${host}/liuwanr/userInfo/queryAccountIsExist`,//查询员工，学生账号是否存在接口
  queryWorkNumberIsExist:`${host}/evaluation/tms/userInfo/queryWorkNumberIsExist`,//查询学号是否存在
  queryStaffWorkNumberIsExist:`${host}/evaluation/tms/system/queryStaffWorkNumberIsExist`,//查询工号是否存在
  querySchool: `${host}/liuwanr/customer/querySchool`, //根据学校名称查询学校信息
 
  queryPersonalCenter:`${host}/liuwanr/personalCenter/queryPersonalCenter`,
  addStaffPro: `${host}/liuwanr/staffProfessionalArchitecture/addStaffProfessionalArchitecture`, //添加员工专业
  queryStaffPro: `${host}/liuwanr/staffProfessionalArchitecture/queryAllStaffProfessionalArchitecture`, //查询员工专业
  deleteStaffPro: `${host}/liuwanr/staffProfessionalArchitecture/deleteStaffProfessionalArchitecture`, //删除员工专业
  deleteStaffGrade: `${host}/liuwanr/staffGrade/deleteStaffGrade`, //删除员工部门
  updateStaffPro: `${host}/liuwanr/staffProfessionalArchitecture/updateStaffProfessionalArchitecture`, //编辑员工专业
  queryStaffGrade: `${host}/liuwanr/staffGrade/queryStaffGrade`, //查询员工部门
  queryStaffGradeDetails: `${host}/liuwanr/staffGrade/queryStaffGradeDetails`, //查询员工部门详情
  addStaffGrade: `${host}/liuwanr/staffGrade/addStaffGrade`, //新增员工部门
  updateStaffGrade: `${host}/liuwanr/staffGrade/updateStaffGrade`, //编辑员工部门
  queryCourseDiscipline: `${host}/liuwanr/course/queryCourseDiscipline`, //查询课程学科
  queryCourseProfessionalClass: `${host}/liuwanr/course/queryCourseProfessionalClass`, //查询专业类
  queryCourseProfessional: `${host}/liuwanr/course/queryCourseProfessional`, //查询专业
  queryPhone: `${host}/liuwanr/user/queryPhone`, //查询电话是否存在
  queryEmail: `${host}/liuwanr/user/queryEmail`, //查询邮箱是否存在
  queryStaffPAN:`${host}/liuwanr/staffProfessionalArchitecture/queryStaffPAN`,//查询员工专业是否存在

  // 个人中心
  userinfo:`${host}/evaluation/tms/userInfo/userinfo`,
  userinfoUpdate:`${host}/evaluation/tms/userInfo/updateUser`,
  sendEmailCode:`${host}/evaluation/tms/user/sendEmailCode`,//发送邮箱验证码
  bingEmail:`${host}/evaluation/tms/user/bingEmail`,//邮箱验证并更新
  sendPhoneCode:`${host}/evaluation/tms/user/sendPhoneCode`,//发送手机验证码
  bindPhone:`${host}/evaluation/tms/user/bindPhone`,//校验手机验证码

  // 测评管理
  list: `${host}/evaluation/tms/questions/list`, //分页加条件查询试题信息
  info: `${host}/evaluation/tms/evaluationrules/info`, //测评规则信息的展示
  update: `${host}/evaluation/tms/evaluationrules/update`, //修改测评规则信息
  delete: `${host}/evaluation/tms/questions/delete`, //批量删除试题信息
  download: `${host}/evaluation/tms/questions/download`, //excel模板文件下载
  import: `${host}/evaluation/tms/questions/import`, //通过excel批量导入
  infoId: `${host}/evaluation/tms/questions/info/`, //根据试题id查询试题详情信息
  isenable: `${host}/evaluation/tms/questions/isenable`, //是否禁用试题
  save: `${host}/evaluation/tms/questions/save`, //新增一道试题
  questionsUpdate: `${host}/evaluation/tms/questions/update`, //根据试题id修改试题信息
  upload: `${host}/evaluation/tms/questions/upload`, //excel模板文件上传
  export_failure: `${host}/evaluation/tms/questions/export_failure`, //导出导入失败的数据和失败原因

  // 考核管理
  assessmentByScreen: `${host}/evaluation/kd/assessment/assessmentByScreen`,
  deleteBatchIds: `${host}/evaluation/kd/assessment/deleteBatchIds`,
  saveAssesment: `${host}/evaluation/kd/assessment/save`,
  editAssessment: `${host}/evaluation/kd/assessment/editAssessment`,
  getMineClass: `${host}/evaluation/kd/assessment/getMineClass`,
  checkAssessmentName: `${host}/evaluation/kd/assessment/checkAssessmentName`,

  expDelete: `${host}/evaluation/tms/exp/delete`, //删除实验教学
  expList: `${host}/evaluation/tms/exp/list`, //实验教学列表
  expSave: `${host}/evaluation/tms/exp/save`, //添加实验教学
  expUpdate: `${host}/evaluation/tms/exp/update`, //修改实验教学
  expInfo: `${host}/evaluation/tms/exp/getById/`, //实验教学详情
  expCheck: `${host}/evaluation/tms/exp/check`, //实验名称判重
  getInvitationCode: `${host}/evaluation/tms/exp/getInvitationCode`, //查询邀请码是否存在
  expInfo1: `${host}/evaluation/tms/exp/upload`, //实验教学提前结束

  queryAllManagements: `${host}/project/ProjectManagement/queryAllManagementsByKD`, //项目管理列表信息
  queryManagements: `${host}/project/ProjectManagement/KDqueryManagements`, //项目管理列表信息
  addRole: `${host}/project/ProjectManagement/addRole`, //新增案例对象
  avgValues: `${host}/project/ProjectManagement/avgValues`, //平均分配分值
  getByRoleId: `${host}/project/ProjectManagement/getByRoleId`, //根据角色id查询信息
  getByjudgmentPointsId: `${host}/project/ProjectManagement/getByjudgmentPointsId`, //实验任务表格信息的展示
  queryAllJudgmentPoints: `${host}/project/ProjectManagement/queryAllJudgmentPoints`, //添加判分点面板的数据展示+条件筛选
  getProjectId: `${host}/project/ProjectManagement/getTrdingJudgmentPointsByKD`, //根据项目管理id查询对应信息
  updateProjectManagement: `${host}/project/ProjectManagement/newUpdateProjectManagementByKD`, //编辑项目管理
  addProjectManagement: `${host}/project/ProjectManagement/newProjectManagementByKD`, //添加项目管理
  removeProjectManagement: `${host}/project/ProjectManagement/removeProjectManagement`, //删除
  getJudgmentPoints: `${host}/project/ProjectManagement/getJudgmentPoints`, //复制项目获取数据
  updateRole: `${host}/project/ProjectManagement/updateRole`, //修改实验数据—角色信息
  isNameExistis: `${host}/project/ProjectManagement/isNameExistis`, //项目名称是否存在
  QueryPfdInformation: `${host}/judgment/pointOfJudgement/queryPfdInformation`, //判分点详细信息
  queryUserIds:`${host}/liuwanr/userInfo/queryUserIds`,

  // 学生管理
  addStudent: `${host}/evaluation/tms/student/addStudent`,
  daleteStudent: `${host}/evaluation/tms/student/daleteStudent`,
  disableAccount: `${host}/evaluation/tms/student/disableAccount`,
  queryStudent: `${host}/evaluation/tms/student/queryStudent`,
  reSetPassword: `${host}/evaluation/tms/student/reSetPassword`,
  updateStudent: `${host}/evaluation/tms/student/updateStudent`,
  download: `${host}/evaluation/tms/student/download`,
  uploadFile: `${host}/evaluation/tms/student/uploadFile`,
  export_failure: `${host}/evaluation/tms/student/export_failure`,
  queryAccountStudent:`${host}/evaluation/tms/student/queryAccount`,
  queryStudentData:`${host}/evaluation/tms/student/queryStudentData`,

  // 员工管理
  addStaff: `${host}/evaluation/tms/system/addStaff`,
  daleteBatchStaff: `${host}/evaluation/tms/system/daleteBatchStaff`,
  queryStaff: `${host}/evaluation/tms/system/queryStaff`,
  querystaffDetail: `${host}/evaluation/tms/system/querystaffDetail`,
  updateStaff: `${host}/evaluation/tms/system/updateStaff`,
  downloadStaff: `${host}/evaluation/tms/system/download`,
  export_failureStaff: `${host}/evaluation/tms/system/export_failure`,
  uploadFileStaff: `${host}/evaluation/tms/system/uploadFile`,
  queryAccountStaff:`${host}/evaluation/tms/system/queryAccount`,
  resetPwd:`${host}/evaluation/tms/system/resetPwd`,

  // 角色权限
  rolePermissionList:`${host}/evaluation/sys-permission/rolePermissionList`,
  saveRolePermission:`${host}/evaluation/sys-permission/saveRolePermission`,
  updateRolePermission:`${host}/evaluation/sys-permission/updateRolePermission`,
  delRolePermission:`${host}/evaluation/sys-permission/delRolePermission`,
  queryPermissionArrById:`${host}/evaluation/sys-permission/queryPermissionArrById`,
  roleTree:`${host}/evaluation/sys-permission/tree`,

  // 成绩管理
  addReport: `${host}/evaluation/Achievement/addReport`,
  deleteReport: `${host}/evaluation/Achievement/deleteReport`,
  deleteReportById: `${host}/evaluation/Achievement/deleteReportById`,
  exportAchievement:`${host}/evaluation/Achievement/exportAchievement`,
  queryAchievement:`${host}/evaluation/Achievement/list`,
  queryAchievementNew:`${host}/evaluation/Achievement/newList`,
  reportList:`${host}/evaluation/Achievement/reportList`,
  getTeachAchievement: `${host}/evaluation/Achievement/getTeachAchievement`,
  queryEvaluationReport:`${host}/evaluation/Achievement/queryEvaluationReport`,
  queryReport:`${host}/evaluation/Achievement/queryReport`,
  getReport: `${host}/evaluation/Achievement/getReport`,
  editScore: `${host}/evaluation/Achievement/editScore`,
  getItemContentByIds:`${host}/kdSys/getItemContentByIds`,
  deleteKdAssessByIds:`${host}/evaluation/kd/assessment/deleteKdAssessByIds`,
  deleteReportByIds:`${host}/evaluation/kd/assessment/deleteReportByIds`,
  getAssessmentList:`${host}/evaluation/kd/assessment/getAssessmentList`,
  getKdAchievement:`${host}/evaluation/kd/assessment/getKdAchievement`,

  // 教师评语
  addComment: `${host}/evaluation/Achievement/addComment`,
  queryComment: `${host}/evaluation/Achievement/queryComment`,
  updateComment:`${host}/evaluation/Achievement/updateComment`,

  // 老师签名照
  daleteSignature: `${host}/evaluation/signature/deleteSignature`,
  querySignature: `${host}/evaluation/signature/querySignature`,
  uploadSignature:`${host}/evaluation/signature/uploadSignature`,
  reportSignature:`${host}/evaluation/signature/reportSignature`,
  selectSignature:`${host}/evaluation/signature/selectSignature`,

  // 科大川大
  queryListTrading: `${host}/judgment/tradingJudgmentPoints/query`,
  queryDetailsTrading: `${host}/judgment/tradingJudgmentPoints/queryDetails`,
  queryPoint: `${host}/kdSys/queryPoint`,
  querySubject: `${host}/kdSys/querySubject`,
  queryItem: `${host}/kdSys/queryItem`,

  // 班级管理
  classList: `${host}/evaluation/class/management/classList`, //班级列表
  saveClass: `${host}/evaluation/class/management/saveClass`, //新增班级
  editClass: `${host}/evaluation/class/management/editClass`, //编辑班级
  deleteClass: `${host}/evaluation/class/management/deleteClass`, //删除班级
  queryStudentList: `${host}/evaluation/class/management/queryStudentList`, //学生列表
  deleteStudents: `${host}/evaluation/class/management/deleteStudents`, //删除学生
  addStudentToClass: `${host}/evaluation/class/management/addStudentToClass`, //新增学生
  queryStudentMessage: `${host}/evaluation/tms/student/queryStudentMessage`, //根据院校和学号查询学生信息
  uploadStudents: `${host}/evaluation/class/management/uploadFile`, //批量导入学生到班级

  classAssessmentList: `${host}/evaluation/class/management/classAssessmentList`, //成绩管理列表
}
